<?php
/**
 * Theme functions and definitions
 *
 * @package home_maintenance_services
 */ 

// enque files
if ( ! function_exists( 'home_maintenance_services_enqueue_styles' ) ) :
	/**
	 * Load assets.
	 *
	 * @since 1.0.0
	 */
	function home_maintenance_services_enqueue_styles() {
		wp_enqueue_style( 'electrician-services-style-parent', get_template_directory_uri() . '/style.css' );
		wp_enqueue_style( 'home-maintenance-services-style', get_stylesheet_directory_uri() . '/style.css', array( 'electrician-services-style-parent' ), '1.0.0' );	

		// Theme Customize CSS.
		require get_parent_theme_file_path( 'inc/extra_customization.php' );
		wp_add_inline_style( 'home-maintenance-services-style',$electrician_services_custom_style );

		require get_theme_file_path( 'inc/extra_customization.php' );
		wp_add_inline_style( 'home-maintenance-services-style',$electrician_services_custom_style );

		// blocks css
        wp_enqueue_style( 'home-maintenance-services-block-style', get_theme_file_uri( '/assets/css/blocks.css' ), array( 'home-maintenance-services-style' ), '1.0' );
	}
endif;
add_action( 'wp_enqueue_scripts', 'home_maintenance_services_enqueue_styles', 99 );

// theme setup
function home_maintenance_services_setup() {
	add_theme_support( 'align-wide' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( "responsive-embeds" );
	add_theme_support( "wp-block-styles" );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support('custom-background',array(
		'default-color' => 'ffffff',
	));
	add_image_size( 'home-maintenance-services-featured-image', 2000, 1200, true );
	add_image_size( 'home-maintenance-services-thumbnail-avatar', 100, 100, true );

	$GLOBALS['content_width'] = 525;
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'home-maintenance-services' ),
	) );

	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo', array(
		'width'       => 250,
		'height'      => 250,
		'flex-width'  => true,
		'flex-height' => true,  
	) );

	/*
	* This theme styles the visual editor to resemble the theme style,
	* specifically font, colors, and column width.
	*/
	add_editor_style( array( 'assets/css/editor-style.css', ) );
}
add_action( 'after_setup_theme', 'home_maintenance_services_setup' );

// widgets
function home_maintenance_services_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'home-maintenance-services' ),
		'id'            => 'sidebar-1',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'home-maintenance-services' ),
		'before_widget' => '<section id="%1$s" class="widget wow zoomIn %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'home-maintenance-services' ),
		'id'            => 'sidebar-2',
		'description'   => __( 'Add widgets here to appear in your pages and posts', 'home-maintenance-services' ),
		'before_widget' => '<section id="%1$s" class="widget wow zoomIn %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar 3', 'home-maintenance-services' ),
		'id'            => 'sidebar-3',
		'description'   => __( 'Add widgets here to appear in your sidebar on blog posts and archive pages.', 'home-maintenance-services' ),
		'before_widget' => '<section id="%1$s" class="widget wow zoomIn %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<div class="widget_container"><h3 class="widget-title">',
		'after_title'   => '</h3></div>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'home-maintenance-services' ),
		'id'            => 'footer-1',
		'description'   => __( 'Add widgets here to appear in your footer.', 'home-maintenance-services' ),
		'before_widget' => '<section id="%1$s" class="widget wow slideInLeft %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'home-maintenance-services' ),
		'id'            => 'footer-2',
		'description'   => __( 'Add widgets here to appear in your footer.', 'home-maintenance-services' ),
		'before_widget' => '<section id="%1$s" class="widget wow slideInLeft %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'home-maintenance-services' ),
		'id'            => 'footer-3',
		'description'   => __( 'Add widgets here to appear in your footer.', 'home-maintenance-services' ),
		'before_widget' => '<section id="%1$s" class="widget wow slideInRight %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'home-maintenance-services' ),
		'id'            => 'footer-4',
		'description'   => __( 'Add widgets here to appear in your footer.', 'home-maintenance-services' ),
		'before_widget' => '<section id="%1$s" class="widget wow slideInRight %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'home_maintenance_services_widgets_init' );

// dropdown
function home_maintenance_services_category_dropdown(){
	if(get_option('home_maintenance_services_category_enable') == true ) {
		return true;
	}
	return false;
}

// remove sections
function home_maintenance_services_customize_register() {
  	global $wp_customize;
	$wp_customize->remove_section( 'electrician_services_pro' );
	$wp_customize->remove_section( 'electrician_services_product_box_section' );
	$wp_customize->remove_setting('electrician_services_footer_text');
	$wp_customize->remove_control('electrician_services_footer_text');
}
add_action( 'customize_register', 'home_maintenance_services_customize_register', 11 );

function home_maintenance_services_customize( $wp_customize ) {

	wp_enqueue_style('customizercustom_css', esc_url( get_stylesheet_directory_uri() ). '/assets/css/customizer.css');

	require get_theme_file_path( 'inc/custom-control.php' );

	// pro section
	$wp_customize->add_section('home_maintenance_services_pro', array(
		'title'    => __('UPGRADE HOME SERVICES PREMIUM', 'home-maintenance-services'),
		'priority' => 1,
	));
	$wp_customize->add_setting('home_maintenance_services_pro', array(
		'default'           => null,
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control(new Home_Maintenance_Services_Pro_Control($wp_customize, 'home_maintenance_services_pro', array(
		'label'    => __('HOME SERVICES PREMIUM', 'home-maintenance-services'),
		'section'  => 'home_maintenance_services_pro',
		'settings' => 'home_maintenance_services_pro',
		'priority' => 1,
	)));

	// Services Section
	$wp_customize->add_section('home_maintenance_services_our_service_section',array(
		'title'	=> __('Services Section','home-maintenance-services'),
		'priority' => 5,
		'panel' => 'electrician_services_custompage_panel',
	));
	$wp_customize->add_setting( 'home_maintenance_services_our_service_heading', array(
		'default'           => '',
		'transport'         => 'refresh',
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wp_customize->add_control( new Home_Maintenance_Services_Customizer_Customcontrol_Section_Heading( $wp_customize, 'home_maintenance_services_our_service_heading', array(
		'label'       => esc_html__( 'Services Section Settings', 'home-maintenance-services' ),	
		'section'     => 'home_maintenance_services_our_service_section',
		'settings'    => 'home_maintenance_services_our_service_heading',
	) ) );
	$wp_customize->add_setting(
		'home_maintenance_services_category_enable',
		array(
			'type'                 => 'option',
			'capability'           => 'edit_theme_options',
			'theme_supports'       => '',
			'default'              => '',
			'transport'            => 'refresh',
			'sanitize_callback'    => 'electrician_services_callback_sanitize_switch',
		)
	);
	$wp_customize->add_control(
		new Home_Maintenance_Services_Customizer_Customcontrol_Switch(
			$wp_customize,
			'home_maintenance_services_category_enable',
			array(
				'settings'        => 'home_maintenance_services_category_enable',
				'section'         => 'home_maintenance_services_our_service_section',
				'label'           => __( 'Check To Show Services Settings', 'home-maintenance-services' ),				
				'choices'		  => array(
					'1'      => __( 'On', 'home-maintenance-services' ),
					'off'    => __( 'Off', 'home-maintenance-services' ),
				),
				'active_callback' => '',
			)
		)
	);
    $wp_customize->add_setting('home_maintenance_services_services_section_title',array(
		'default' => '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('home_maintenance_services_services_section_title',array(
		'label'	=> __('Section Title','home-maintenance-services'),
		'section' => 'home_maintenance_services_our_service_section',
		'type' => 'text',
		'active_callback' => 'home_maintenance_services_category_dropdown',
	));

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_pst[]= 'select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_pst[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('home_maintenance_services_category_setting',array(
		'default' => 'select',
		'sanitize_callback' => 'electrician_services_sanitize_choices',
	));
	$wp_customize->add_control('home_maintenance_services_category_setting',array(
		'type' => 'select',
		'choices' => $cat_pst,
		'label' => __('Select Category to display Post','home-maintenance-services'),
		'section' => 'home_maintenance_services_our_service_section',
		'active_callback' => 'home_maintenance_services_category_dropdown',

	));
	$wp_customize->add_setting('home_maintenance_services_footer_text',array(
			'default'	=> 'Home Maintenance Services WordPress Theme',
			'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('home_maintenance_services_footer_text',array(
			'label'	=> esc_html__('Copyright Text','home-maintenance-services'),
			'section'	=> 'electrician_services_footer_copyright',
			'type'		=> 'textarea'
	));
}
add_action( 'customize_register', 'home_maintenance_services_customize' );

function home_maintenance_services_enqueue_comments_reply() {
  if( is_singular() && comments_open() && ( get_option( 'thread_comments' ) == 1) ) {
    // Load comment-reply.js (into footer)
    wp_enqueue_script( 'comment-reply', '/wp-includes/js/comment-reply.min.js', array(), false, true );
  }
}
add_action(  'wp_enqueue_scripts', 'home_maintenance_services_enqueue_comments_reply' );

// Footer Text
function home_maintenance_services_copyright_link() {
    $home_maintenance_services_footer_text = get_theme_mod('home_maintenance_services_footer_text', esc_html__('Home Maintenance Services WordPress Theme', 'home-maintenance-services'));
    $home_maintenance_services_credit_link = esc_url('https://www.ovationthemes.com/wordpress/free-wordpress-maintenance-services-theme/');

    echo '<a href="' . $home_maintenance_services_credit_link . '" target="_blank">' . esc_html($home_maintenance_services_footer_text) . '<span class="footer-copyright">' . esc_html__(' By Ovation Themes', 'home-maintenance-services') . '</span></a>';
}

if ( ! defined( 'HOME_MAINTENANCE_SERVICES_PRO_LINK' ) ) {
	define('HOME_MAINTENANCE_SERVICES_PRO_LINK',__('https://www.ovationthemes.com/wordpress/maintenance-wordpress-theme/','home-maintenance-services'));
}

if ( ! defined( 'ELECTRICIAN_SERVICES_SUPPORT' ) ) {
	define('ELECTRICIAN_SERVICES_SUPPORT',__('https://wordpress.org/support/theme/home-maintenance-services/','home-maintenance-services'));
}
if ( ! defined( 'ELECTRICIAN_SERVICES_REVIEW' ) ) {
	define('ELECTRICIAN_SERVICES_REVIEW',__('https://wordpress.org/support/theme/home-maintenance-services/reviews/#new-post','home-maintenance-services'));
}
if ( ! defined( 'ELECTRICIAN_SERVICES_LIVE_DEMO' ) ) {
	define('ELECTRICIAN_SERVICES_LIVE_DEMO',__('https://www.ovationthemes.com/demos/home-maintenance-services/','home-maintenance-services'));
}
if ( ! defined( 'ELECTRICIAN_SERVICES_BUY_PRO' ) ) {
	define('ELECTRICIAN_SERVICES_BUY_PRO',__('https://www.ovationthemes.com/wordpress/maintenance-wordpress-theme/','home-maintenance-services'));
}
if ( ! defined( 'ELECTRICIAN_SERVICES_PRO_DOC' ) ) {
	define('ELECTRICIAN_SERVICES_PRO_DOC',__('https://www.ovationthemes.com/docs/ot-home-maintenance-services-pro-doc/','home-maintenance-services'));
}
if ( ! defined( 'ELECTRICIAN_SERVICES_FREE_DOC' ) ) {
define('ELECTRICIAN_SERVICES_FREE_DOC',__('https://ovationthemes.com/docs/ot-home-maintenance-services-free-doc','home-maintenance-services'));
}
if ( ! defined( 'ELECTRICIAN_SERVICES_THEME_NAME' ) ) {
	define('ELECTRICIAN_SERVICES_THEME_NAME',__('Premium Home Maintenance Theme','home-maintenance-services'));
}

/* Pro control */
if (class_exists('WP_Customize_Control') && !class_exists('Home_Maintenance_Services_Pro_Control')):
    class Home_Maintenance_Services_Pro_Control extends WP_Customize_Control{

    public function render_content(){?>
        <label style="overflow: hidden; zoom: 1;">
            <div class="col-md upsell-btn">
                <a href="<?php echo esc_url( HOME_MAINTENANCE_SERVICES_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE HOME SERVICES PREMIUM','home-maintenance-services');?> </a>
            </div>
            <div class="col-md">
                <img class="home_maintenance_services_img_responsive " src="<?php echo esc_url( get_stylesheet_directory_uri() ); ?>/screenshot.png">
            </div>
            <div class="col-md">
                <h3 style="margin-top:10px; margin-left: 20px; text-decoration:underline; color:#333;"><?php esc_html_e('HOME SERVICES PREMIUM - Features', 'home-maintenance-services'); ?></h3>
                <ul style="padding-top:10px">
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Responsive Design', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Boxed or fullwidth layout', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Shortcode Support', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Demo Importer', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Section Reordering', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Contact Page Template', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Multiple Blog Layouts', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Unlimited Color Options', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Designed with HTML5 and CSS3', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Customizable Design & Code', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Cross Browser Support', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Detailed Documentation Included', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Stylish Custom Widgets', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Patterns Background', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('WPML Compatible (Translation Ready)', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Woo-commerce Compatible', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Full Support', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('10+ Sections', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Live Customizer', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('AMP Ready', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Clean Code', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('SEO Friendly', 'home-maintenance-services');?> </li>
                    <li class="upsell-home_maintenance_services"> <div class="dashicons dashicons-yes"></div> <?php esc_html_e('Supper Fast', 'home-maintenance-services');?> </li>
                </ul>
            </div>
            <div class="col-md upsell-btn upsell-btn-bottom">
                <a href="<?php echo esc_url( HOME_MAINTENANCE_SERVICES_PRO_LINK ); ?>" target="blank" class="btn btn-success btn"><?php esc_html_e('UPGRADE HOME SERVICES PREMIUM','home-maintenance-services');?> </a>
            </div>
        </label>
    <?php } }
endif;